@@ -12,12 +12,13 @@ class JacTests(TestCaseHelper, TestCase):
 
     def setUp(self):
         super().setUp()
+        self.meta = MetaService()
 
     def tearDown(self):
         super().tearDown()
 
     def test_rand_std(self):
-        sent = Sentinel(m_id="anon", h=MetaService().hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(stc.rand_std)
         test_walker = sent.run_architype("init")
@@ -30,7 +31,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertGreater(len(report[3]), len(report[2]))
 
     def test_file_io(self):
-        sent = Sentinel(m_id="anon", h=MetaService().hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(stc.file_io)
         test_walker = sent.run_architype("init")
@@ -40,7 +41,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(report, ['{"a": 10}{"a": 10}'])
 
     def test_std_used_in_node_has_var(self):
-        sent = Sentinel(m_id="anon", h=MetaService().hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(stc.std_used_in_node_has_var)
         test_walker = sent.run_architype("init")
